@@ -3,12 +3,7 @@
 
 """Test interact and interactive."""
 
-from __future__ import print_function
-
-try:
-    from unittest.mock import patch
-except ImportError:
-    from mock import patch
+from unittest.mock import patch
 
 import os
 from collections import OrderedDict
@@ -16,10 +11,9 @@ import pytest
 
 import ipywidgets as widgets
 
-from traitlets import TraitError
+from traitlets import TraitError, Float
 from ipywidgets import (interact, interact_manual, interactive,
-    interaction, Output)
-from ipython_genutils.py3compat import annotate
+                        interaction, Output, Widget)
 
 #-----------------------------------------------------------------------------
 # Utility stuff
@@ -50,15 +44,15 @@ def check_widget(w, **d):
             assert w.__class__ is expected
         else:
             value = getattr(w, attr)
-            assert value == expected, "%s.%s = %r != %r" % (w.__class__.__name__, attr, value, expected)
+            assert value == expected, "{}.{} = {!r} != {!r}".format(w.__class__.__name__, attr, value, expected)
 
             # For numeric values, the types should match too
             if isinstance(value, (int, float)):
                 tv = type(value)
                 te = type(expected)
-                assert tv is te, "type(%s.%s) = %r != %r" % (w.__class__.__name__, attr, tv, te)
+                assert tv is te, "type({}.{}) = {!r} != {!r}".format(w.__class__.__name__, attr, tv, te)
 
-def check_widgets(container, **to_check):
+def check_widget_children(container, **to_check):
     """Check that widgets are created as expected"""
     # build a widget dictionary, so it matches
     widgets = {}
@@ -72,7 +66,7 @@ def check_widgets(container, **to_check):
 
 
 def test_single_value_string():
-    a = u'hello'
+    a = 'hello'
     c = interactive(f, a=a)
     w = c.children[0]
     check_widget(w,
@@ -150,7 +144,7 @@ def test_list_str():
         _options_labels=tuple(values),
         _options_values=tuple(values),
     )
-    check_widgets(c, lis=d)
+    check_widget_children(c, lis=d)
 
 def test_list_int():
     values = [3, 1, 2]
@@ -164,7 +158,7 @@ def test_list_int():
         _options_labels=tuple(str(v) for v in values),
         _options_values=tuple(values),
     )
-    check_widgets(c, lis=d)
+    check_widget_children(c, lis=d)
 
 def test_list_tuple():
     values = [(3, 300), (1, 100), (2, 200)]
@@ -178,7 +172,7 @@ def test_list_tuple():
         _options_labels=("3", "1", "2"),
         _options_values=(300, 100, 200),
     )
-    check_widgets(c, lis=d)
+    check_widget_children(c, lis=d)
 
 def test_list_tuple_invalid():
     for bad in [
@@ -205,7 +199,6 @@ def test_dict():
         )
         check_widget(w, **check)
 
-
 def test_ordereddict():
     from collections import OrderedDict
     items = [(3, 300), (1, 100), (2, 200)]
@@ -220,7 +213,7 @@ def test_ordereddict():
         _options_labels=("3", "1", "2"),
         _options_values=(300, 100, 200),
     )
-    check_widgets(c, lis=d)
+    check_widget_children(c, lis=d)
 
 def test_iterable():
     def yield_values():
@@ -237,7 +230,7 @@ def test_iterable():
         _options_labels=("3", "1", "2"),
         _options_values=(3, 1, 2),
     )
-    check_widgets(c, lis=d)
+    check_widget_children(c, lis=d)
 
 def test_iterable_tuple():
     values = [(3, 300), (1, 100), (2, 200)]
@@ -251,15 +244,11 @@ def test_iterable_tuple():
         _options_labels=("3", "1", "2"),
         _options_values=(300, 100, 200),
     )
-    check_widgets(c, lis=d)
+    check_widget_children(c, lis=d)
 
 def test_mapping():
-    try:
-        # Python 3
-        from collections.abc import Mapping
-    except ImportError:
-        # Python 2
-        from collections import Mapping
+    from collections.abc import Mapping
+    from collections import OrderedDict
     class TestMapping(Mapping):
         def __init__(self, values):
             self.values = values
@@ -284,116 +273,7 @@ def test_mapping():
         _options_labels=("3", "1", "2"),
         _options_values=(300, 100, 200),
     )
-    check_widgets(c, lis=d)
-
-
-def test_defaults():
-    @annotate(n=10)
-    def f(n, f=4.5, g=1):
-        pass
-
-    c = interactive(f)
-    check_widgets(c,
-        n=dict(
-            cls=widgets.IntSlider,
-            value=10,
-        ),
-        f=dict(
-            cls=widgets.FloatSlider,
-            value=4.5,
-        ),
-        g=dict(
-            cls=widgets.IntSlider,
-            value=1,
-        ),
-    )
-
-def test_default_values():
-    @annotate(n=10, f=(0, 10.), g=5, h=OrderedDict([('a',1), ('b',2)]), j=['hi', 'there'])
-    def f(n, f=4.5, g=1, h=2, j='there'):
-        pass
-
-    c = interactive(f)
-    check_widgets(c,
-        n=dict(
-            cls=widgets.IntSlider,
-            value=10,
-        ),
-        f=dict(
-            cls=widgets.FloatSlider,
-            value=4.5,
-        ),
-        g=dict(
-            cls=widgets.IntSlider,
-            value=5,
-        ),
-        h=dict(
-            cls=widgets.Dropdown,
-            options=OrderedDict([('a',1), ('b',2)]),
-            value=2
-        ),
-        j=dict(
-            cls=widgets.Dropdown,
-            options=('hi', 'there'),
-            value='there'
-        ),
-    )
-
-def test_default_out_of_bounds():
-    @annotate(f=(0, 10.), h={'a': 1}, j=['hi', 'there'])
-    def f(f='hi', h=5, j='other'):
-        pass
-
-    c = interactive(f)
-    check_widgets(c,
-        f=dict(
-            cls=widgets.FloatSlider,
-            value=5.,
-        ),
-        h=dict(
-            cls=widgets.Dropdown,
-            options={'a': 1},
-            value=1,
-        ),
-        j=dict(
-            cls=widgets.Dropdown,
-            options=('hi', 'there'),
-            value='hi',
-        ),
-    )
-
-def test_annotations():
-    @annotate(n=10, f=widgets.FloatText())
-    def f(n, f):
-        pass
-
-    c = interactive(f)
-    check_widgets(c,
-        n=dict(
-            cls=widgets.IntSlider,
-            value=10,
-        ),
-        f=dict(
-            cls=widgets.FloatText,
-        ),
-    )
-
-def test_priority():
-    @annotate(annotate='annotate', kwarg='annotate')
-    def f(kwarg='default', annotate='default', default='default'):
-        pass
-
-    c = interactive(f, kwarg='kwarg')
-    check_widgets(c,
-        kwarg=dict(
-            cls=widgets.Text,
-            value='kwarg',
-        ),
-        annotate=dict(
-            cls=widgets.Text,
-            value='annotate',
-        ),
-    )
+    check_widget_children(c, lis=d)
 
 def test_decorator_kwarg(clear_display):
     with patch.object(interaction, 'display', record_display):
@@ -408,7 +288,7 @@ def test_decorator_kwarg(clear_display):
     )
 
 def test_interact_instancemethod(clear_display):
-    class Foo(object):
+    class Foo:
         def show(self, x):
             print(x)
 
@@ -482,8 +362,8 @@ def test_call_decorated_on_trait_change(clear_display):
         def foo(a='default'):
             d['a'] = a
             return a
-    assert len(displayed) == 1
-    w = displayed[0].children[0]
+    assert len(displayed) == 2 # display the result and the interact
+    w = displayed[1].children[0]
     check_widget(w,
         cls=widgets.Text,
         value='default',
@@ -497,7 +377,7 @@ def test_call_decorated_on_trait_change(clear_display):
     with patch.object(interaction, 'display', record_display):
         w.value = 'called'
     assert d['a'] == 'called'
-    assert len(displayed) == 2
+    assert len(displayed) == 3
     assert w.value == displayed[-1]
 
 def test_call_decorated_kwargs_on_trait_change(clear_display):
@@ -508,8 +388,8 @@ def test_call_decorated_kwargs_on_trait_change(clear_display):
         def foo(a='default'):
             d['a'] = a
             return a
-    assert len(displayed) == 1
-    w = displayed[0].children[0]
+    assert len(displayed) == 2 # display the result and the interact
+    w = displayed[1].children[0]
     check_widget(w,
         cls=widgets.Text,
         value='kwarg',
@@ -523,7 +403,7 @@ def test_call_decorated_kwargs_on_trait_change(clear_display):
     with patch.object(interaction, 'display', record_display):
         w.value = 'called'
     assert d['a'] == 'called'
-    assert len(displayed) == 2
+    assert len(displayed) == 3
     assert w.value == displayed[-1]
 
 
@@ -563,6 +443,16 @@ def test_custom_description():
     w.value = 'different text'
     assert d == {'b': 'different text'}
 
+def test_raises_on_non_value_widget():
+    """ Test that passing in a non-value widget raises an error """
+
+    class BadWidget(Widget):
+        """ A widget that contains a `value` traitlet """
+        value = Float()
+
+    with pytest.raises(TypeError, match=".* not a ValueWidget.*"):
+        interactive(f, b=BadWidget())
+
 def test_interact_manual_button():
     c = interact.options(manual=True).widget(f)
     w = c.children[0]
@@ -696,14 +586,14 @@ def test_multiple_selection():
     check_widget(w, options={1:1})
 
     # updating
+    w.options = (1,)
     with pytest.raises(TraitError):
         w.value = (2,)
-    check_widget(w, options={1:1})
-
+    check_widget(w, options=(1,) )
 
 def test_interact_noinspect():
-    a = u'hello'
-    c = interactive(print, a=a)
+    a = 'hello'
+    c = interactive(dict, a=a)
     w = c.children[0]
     check_widget(w,
         cls=widgets.Text,
